'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var React = _interopRequireWildcard(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Icon = require('./Icon');

var _Icon2 = _interopRequireDefault(_Icon);

var _constants = require('./utils/constants');

var _utils = require('./utils');

var _TypeDefinition = require('./utils/TypeDefinition');

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _defaults(obj, defaults) { var keys = Object.getOwnPropertyNames(defaults); for (var i = 0; i < keys.length; i++) { var key = keys[i]; var value = Object.getOwnPropertyDescriptor(defaults, key); if (value && value.configurable && obj[key] === undefined) { Object.defineProperty(obj, key, value); } } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : _defaults(subClass, superClass); }

var Message = function (_React$Component) {
  _inherits(Message, _React$Component);

  function Message() {
    _classCallCheck(this, Message);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this));

    _this.addPrefix = function (name) {
      return (0, _utils.prefix)(_this.props.classPrefix)(name);
    };

    _this.handleClose = function () {
      var onClose = _this.props.onClose;

      _this.setState({ display: 'hiding' });

      setTimeout(function () {
        return _this.setState({ display: 'hide' }, function () {
          onClose && onClose();
        });
      }, 1000);
    };

    _this.state = {
      display: 'show'
    };
    return _this;
  }

  Message.prototype.renderCloseButton = function renderCloseButton(closeLabel) {
    return React.createElement(
      'button',
      { type: 'button', className: this.addPrefix('btn-close'), onClick: this.handleClose },
      React.createElement(
        'span',
        { 'aria-hidden': 'true' },
        '\xD7'
      ),
      React.createElement(
        'span',
        { className: 'sr-only' },
        closeLabel
      )
    );
  };

  Message.prototype.render = function render() {
    var _classNames;

    var _props = this.props,
        className = _props.className,
        classPrefix = _props.classPrefix,
        onClose = _props.onClose,
        type = _props.type,
        title = _props.title,
        description = _props.description,
        closeLabel = _props.closeLabel,
        closable = _props.closable,
        full = _props.full,
        showIcon = _props.showIcon,
        props = _objectWithoutProperties(_props, ['className', 'classPrefix', 'onClose', 'type', 'title', 'description', 'closeLabel', 'closable', 'full', 'showIcon']);

    var display = this.state.display;


    if (display === 'hide') {
      return null;
    }

    var hasTitle = !!title;
    var hasDesc = !!description;
    var classes = (0, _classnames2.default)(classPrefix, className, this.addPrefix(type), this.addPrefix(display), (_classNames = {}, _classNames[this.addPrefix('has-title')] = hasTitle, _classNames[this.addPrefix('has-icon')] = showIcon, _classNames[this.addPrefix('full')] = full, _classNames));

    return React.createElement(
      'div',
      _extends({}, props, { className: classes }),
      React.createElement(
        'div',
        { className: this.addPrefix('container') },
        closable && this.renderCloseButton(closeLabel),
        showIcon && React.createElement(
          'div',
          { className: this.addPrefix('icon-wrapper') },
          React.createElement(_Icon2.default, { icon: _constants.STATUS_ICON_NAMES[type] })
        ),
        React.createElement(
          'div',
          { className: this.addPrefix('content') },
          hasTitle && React.createElement(
            'h5',
            { className: this.addPrefix('header') },
            title
          ),
          hasDesc && React.createElement(
            'div',
            { className: this.addPrefix('body') },
            description
          )
        )
      )
    );
  };

  return Message;
}(React.Component);

Message.defaultProps = {
  type: 'info',
  closeLabel: 'Close'
};
Message.handledProps = ['className', 'classPrefix', 'closable', 'closeLabel', 'description', 'full', 'onClose', 'showIcon', 'title', 'type'];
Message.propTypes = {
  type: function type() {
    return (typeof _TypeDefinition.bpfrpt_proptype_Types === 'function' ? _TypeDefinition.bpfrpt_proptype_Types.isRequired ? _TypeDefinition.bpfrpt_proptype_Types.isRequired : _TypeDefinition.bpfrpt_proptype_Types : _propTypes2.default.shape(_TypeDefinition.bpfrpt_proptype_Types).isRequired).apply(this, arguments);
  },
  className: _propTypes2.default.string,
  onClose: _propTypes2.default.func,
  closable: _propTypes2.default.bool,
  closeLabel: _propTypes2.default.string.isRequired,
  title: _propTypes2.default.node,
  description: _propTypes2.default.node,
  showIcon: _propTypes2.default.bool,
  full: _propTypes2.default.bool,
  classPrefix: _propTypes2.default.string.isRequired
};
exports.default = (0, _utils.defaultProps)({
  classPrefix: 'message'
})(Message);