'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var React = _interopRequireWildcard(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _setDisplayName = require('recompose/setDisplayName');

var _setDisplayName2 = _interopRequireDefault(_setDisplayName);

var _SafeAnchor = require('./SafeAnchor');

var _SafeAnchor2 = _interopRequireDefault(_SafeAnchor);

var _Icon = require('./Icon');

var _Icon2 = _interopRequireDefault(_Icon);

var _Tooltip = require('./Tooltip');

var _Tooltip2 = _interopRequireDefault(_Tooltip);

var _Whisper = require('./Whisper');

var _Whisper2 = _interopRequireDefault(_Whisper);

var _utils = require('./utils');

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _defaults(obj, defaults) { var keys = Object.getOwnPropertyNames(defaults); for (var i = 0; i < keys.length; i++) { var key = keys[i]; var value = Object.getOwnPropertyDescriptor(defaults, key); if (value && value.configurable && obj[key] === undefined) { Object.defineProperty(obj, key, value); } } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : _defaults(subClass, superClass); }

var addTooltip = function addTooltip(children, tip) {
  return React.createElement(
    _Whisper2.default,
    { speaker: React.createElement(
        _Tooltip2.default,
        null,
        tip
      ), placement: 'right' },
    children
  );
};

addTooltip.handledProps = [];

var NavItem = function (_React$Component) {
  _inherits(NavItem, _React$Component);

  function NavItem() {
    var _temp, _this, _ret;

    _classCallCheck(this, NavItem);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.handleClick = function (event) {
      var _this$props = _this.props,
          onSelect = _this$props.onSelect,
          disabled = _this$props.disabled,
          eventKey = _this$props.eventKey;

      if (onSelect && !disabled) {
        onSelect(eventKey, event);
      }
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  NavItem.prototype.render = function render() {
    var _classNames;

    var _props = this.props,
        active = _props.active,
        disabled = _props.disabled,
        onClick = _props.onClick,
        className = _props.className,
        classPrefix = _props.classPrefix,
        style = _props.style,
        eventKey = _props.eventKey,
        children = _props.children,
        icon = _props.icon,
        tabIndex = _props.tabIndex,
        hasTooltip = _props.hasTooltip,
        divider = _props.divider,
        panel = _props.panel,
        Component = _props.componentClass,
        props = _objectWithoutProperties(_props, ['active', 'disabled', 'onClick', 'className', 'classPrefix', 'style', 'eventKey', 'children', 'icon', 'tabIndex', 'hasTooltip', 'divider', 'panel', 'componentClass']);

    var addPrefix = (0, _utils.prefix)(classPrefix);
    var classes = (0, _classnames2.default)(classPrefix, className, (_classNames = {}, _classNames[addPrefix('active')] = active, _classNames[addPrefix('disabled')] = disabled, _classNames));

    if (divider) {
      return React.createElement('li', {
        role: 'separator',
        style: style,
        className: (0, _classnames2.default)(addPrefix('divider'), className)
      });
    }

    if (panel) {
      return React.createElement(
        'li',
        { style: style, className: (0, _classnames2.default)(addPrefix('panel'), className) },
        children
      );
    }

    var item = React.createElement(
      Component,
      _extends({}, props, {
        role: 'button',
        tabIndex: tabIndex,
        className: addPrefix('content'),
        disabled: disabled,
        onClick: (0, _utils.createChainedFunction)(onClick, this.handleClick)
      }),
      icon,
      React.createElement(
        'span',
        { className: addPrefix('text') },
        children
      )
    );

    return React.createElement(
      'li',
      { role: 'presentation', className: classes, style: style },
      hasTooltip ? addTooltip(item, children) : item
    );
  };

  return NavItem;
}(React.Component);

NavItem.defaultProps = {
  tabIndex: 0
};
NavItem.handledProps = ['active', 'children', 'className', 'classPrefix', 'componentClass', 'disabled', 'divider', 'eventKey', 'hasTooltip', 'icon', 'onClick', 'onSelect', 'panel', 'style', 'tabIndex'];
NavItem.propTypes = {
  active: _propTypes2.default.bool,
  disabled: _propTypes2.default.bool,
  className: _propTypes2.default.string,
  classPrefix: _propTypes2.default.string,
  divider: _propTypes2.default.bool,
  panel: _propTypes2.default.bool,
  onClick: _propTypes2.default.func,
  style: _propTypes2.default.object,
  icon: _propTypes2.default.node,
  onSelect: _propTypes2.default.func,
  children: _propTypes2.default.node,
  eventKey: _propTypes2.default.any,
  tabIndex: _propTypes2.default.number,
  hasTooltip: _propTypes2.default.bool,
  componentClass: function componentClass() {
    return (typeof (React.ElementType == null ? {} : React.ElementType) === 'function' ? _propTypes2.default.instanceOf(React.ElementType == null ? {} : React.ElementType).isRequired : _propTypes2.default.any.isRequired).apply(this, arguments);
  }
};
exports.default = (0, _setDisplayName2.default)('NavItem')((0, _utils.defaultProps)({
  classPrefix: 'nav-item',
  componentClass: _SafeAnchor2.default
})(NavItem));